<?php

if (!defined('FORUM_ROOT'))
	define('FORUM_ROOT', '../../');
	
require FORUM_ROOT.'include/common.php';
require FORUM_ROOT.'include/common_admin.php';

// Load the language file
require FORUM_ROOT.'lang/'.$forum_user['language'].'/common.php';
require FORUM_ROOT.'lang/'.$forum_user['language'].'/admin_common.php';
require FORUM_ROOT.'lang/'.$forum_user['language'].'/post.php';

if ($forum_user['g_id'] != FORUM_ADMIN)
	message($lang_common['No permission']);

$fid = isset($_GET['fid']) ? intval($_GET['fid']) : 0;
if ($fid < 1)
	message('Форум не выбран');

$errors = array();

if (isset($_POST['add_topic']))
{
	if ($forum_config['o_pan_posting_users_group'] == '0')
		$errors[] = 'Группа пользователей для постинга "Непроверенные/Заблокированные". Пожалуйста, выберите в <a href="'.forum_link($forum_url['pan_posting_options']).'" target="_blank">настройках</a> определенную группу для активации новых пользователей.';

	$req_guest = forum_trim($_POST['req_guest']);
	if (isset($_POST['req_username']))
	{
		$poster_name = !empty($_POST['req_guest']) ? forum_trim($_POST['req_guest']) : forum_trim($_POST['req_username']);
	} else {
		$errors[] = 'Пользователь не выбран! Вначале установите время и выберите пользователя из появившегося списка или введите имя нового пользователя.';
	}

	$query = array(
		'SELECT'	=> 'id, forum_name',
		'FROM'		=> 'forums',
		'WHERE'		=> 'id='.$fid
	);
	$result = $forum_db->query_build($query) or error(__FILE__, __LINE__);
	$fetch_forum_info = $forum_db->fetch_assoc($result);

	$subject = forum_trim($_POST['req_subject']);
	
	if ($subject == '')
		$errors[] = $lang_post['No subject'];
	else if (utf8_strlen($subject) > 70)
		$errors[] = $lang_post['Too long subject'];
	else if ($forum_config['p_subject_all_caps'] == '0' && check_is_all_caps($subject) && !$forum_page['is_admmod'])
		$errors[] = $lang_post['All caps subject'];

	$query = array(
		'SELECT'	=> 'id, subject',
		'FROM'		=> 'topics',
	);
	$result = $forum_db->query_build($query) or error(__FILE__, __LINE__);

	$res = array();
	while($fetch_subject = $forum_db->fetch_assoc($result) )
	{
		$res[] = $fetch_subject;
		$row = $fetch_subject['subject'];
		similar_text(utf8_strtolower($row), utf8_strtolower($subject), $part);
		$similarity_part = floor($part);

		//порог уникальности заголовка в процентах
		$uniqueness = $forum_config['o_pan_posting_unique_subject'];
		if ($similarity_part > $uniqueness) { 
			$errors[] = 'Неуникальность заголовка превысила '.$similarity_part.' % в теме <a href="'.forum_link($forum_url['topic'], $fetch_subject['id']).'" target="_blank">'.$fetch_subject['subject'].'</a>';
		}
	}
	
	// Get the quote and quote poster
	$query = array(
		'SELECT'	=> 'u.id, u.username, u.registered',
		'FROM'		=> 'users AS u',
		'WHERE'		=> 'u.username=\''.$forum_db->escape($poster_name).'\''
	);
	$result = $forum_db->query_build($query) or error(__FILE__, __LINE__);
	$fetch_user = $forum_db->fetch_assoc($result);
	
	// Convert date & time
	$req_date = !empty($_POST['req_date']) ? $_POST['req_date'] : date("Y-m-d", time());
	$req_time = !empty($_POST['req_time']) ? $_POST['req_time'] : date("H:i", time());
	$date = strtotime($req_date.' '.$req_time.':'.date("s", time()));

	//Validate date register amd posted
	if ($date < $fetch_user['registered'])
		$errors[] = 'Пользователь тогда еще небыл зарегистрирован. Выберите другого пользователя или дату позднее: '.date("d.m.Y H:i", $fetch_user['registered']);

	//проверка на дубли юзеров в нижнем регистре
	if (!empty($req_guest) && (mb_strtolower($fetch_user['username'], 'UTF-8') == mb_strtolower($req_guest, 'UTF-8')))
		$errors[] = 'Пользователь с логином <strong>'.$fetch_user['username'].'</strong> уже существует!';

	// Clean up message from POST
	$message = forum_linebreaks(forum_trim($_POST['req_message']));
	
	if (strlen($message) > FORUM_MAX_POSTSIZE_BYTES)
		$errors[] = sprintf($lang_post['Too long message'], forum_number_format(strlen($message)), forum_number_format(FORUM_MAX_POSTSIZE_BYTES));
	else if ($forum_config['p_message_all_caps'] == '0' && check_is_all_caps($message) && !$forum_page['is_admmod'])
		$errors[] = $lang_post['All caps message'];
	
	// Validate BBCode syntax
	if ($forum_config['p_message_bbcode'] == '1' || $forum_config['o_make_links'] == '1')
	{
		if (!defined('FORUM_PARSER_LOADED'))
			require FORUM_ROOT.'include/parser.php';
	
		$message = preparse_bbcode($message, $errors);
	}
	
	if ($message == '')
		$errors[] = $lang_post['No message'];
	
	$hide_smilies = isset($_POST['hide_smilies']) ? 1 : 0;
	$subscribe = isset($_POST['subscribe']) ? 1 : 0;
	
	if (!empty($req_guest) && ($fetch_user['username'] != $req_guest) && empty($errors))
	{
		//Add New User
		$registered = ($date < time()) ? ($date - $forum_config['o_pan_posting_users_reg_time']) : time();
		
		$salt = random_key(12);
		$password_hash = forum_hash($forum_config['o_pan_posting_users_pass'], $salt);
		
		$user_info = array(
			'username'			=> $poster_name,
			'group_id'			=> $forum_config['o_pan_posting_users_group'],
			'password'			=> $password_hash,
			'email'				=> $forum_config['o_pan_posting_users_email'],
			'email_setting'		=> $forum_config['o_default_email_setting'],
			'timezone'			=> $forum_config['o_default_timezone'],
			'dst'				=> $forum_config['o_default_dst'],
			'language'			=> $forum_config['o_default_lang'],
			'style'				=> $forum_config['o_default_style'],
			'registered'		=> $registered,
			'registration_ip'	=> get_remote_address(),
			'salt'				=> $salt,
			'activate_key'		=> 'NULL',
		);
		
		add_user($user_info, $new_uid);
	
	}
	
	// Did everything go according to plan?
	if (empty($errors) && $fid)
	{
		if ($date < time())
		{
			//Update Method from Standart PunBB 22/10/2016
			$post_info = array(
				'is_guest'		=> '',
				'poster'		=> $poster_name,
				'poster_id'		=> isset($new_uid) ? $new_uid : $fetch_user['id'],
				'poster_email'	=> null,
				'subject'		=> $subject,
				'message'		=> $message,
				'hide_smilies'	=> $hide_smilies,
				'posted'		=> $date,
				'subscribe'		=> '0',
				'forum_id'		=> $fid,
				'forum_name'	=> isset($fetch_forum_info['forum_name']) ? $fetch_forum_info['forum_name'] : '',
				'update_user'	=> true,
				'update_unread'	=> true
			);
//			($hook = get_hook('po_pre_add_topic')) ? eval($hook) : null;
			add_topic($post_info, $new_tid, $new_pid);
			
			redirect(forum_link($forum_url['pan_posting_new_post'], $new_tid), 'Added');
			
		} else {
			
			$post_info = array(
				'is_guest'		=> '',
				'poster'		=> $poster_name,
				'poster_id'		=> isset($new_uid) ? $new_uid : $fetch_user['id'],
				'poster_email'	=> '',
				'subject'		=> $subject,
				'message'		=> $message,
				'hide_smilies'	=> $hide_smilies,
				'posted'		=> $date,
				'subscribe'		=> '0',
				'forum_id'		=> $fid,
				'forum_name'	=> '',
				'update_user'	=> true,
				'update_unread'	=> true,
				'post_status'	=> '0',
				'first_post'	=> '1',
				'num_posts' 	=> '1'
			);
			
			// Add the topic
			$query = array(
				'INSERT'	=> 'poster, poster_id, poster_email, subject, message, hide_smilies, posted, subscribe, forum_id, forum_name, update_user, update_unread, post_status, first_post, num_posts',
				'INTO'		=> 'pan_posting_topic',
				'VALUES'	=> '\''.$forum_db->escape($post_info['poster']).'\', \''.$forum_db->escape($post_info['poster_id']).'\', \''.$forum_db->escape($post_info['poster_email']).'\', \''.$forum_db->escape($post_info['subject']).'\', \''.$forum_db->escape($post_info['message']).'\', '.$post_info['hide_smilies'].', \''.$post_info['posted'].'\', \''.$forum_db->escape($post_info['subscribe']).'\', \''.$post_info['forum_id'].'\', \''.$forum_db->escape($post_info['forum_name']).'\', '.$post_info['update_user'].', '.$post_info['update_unread'].', \''.$forum_db->escape($post_info['post_status']).'\', \''.$forum_db->escape($post_info['first_post']).'\', \''.$post_info['num_posts'].'\''
			);
			
			$forum_db->query_build($query) or error(__FILE__, __LINE__);
			$new_tid = $forum_db->insert_id();

			// Update Old Topic For Delete
			$query = array(
				'UPDATE'	=> 'pan_posting_topic',
				'SET'		=> 'topic_id_now='.$new_tid,
				'WHERE'		=> 'id='.$new_tid
			);
			
			$forum_db->query_build($query) or error(__FILE__, __LINE__);
			
			redirect(forum_link($forum_url['pan_posting_view_topic'], $new_tid), 'Added');
		}
		
	}
	
}

$forum_page['crumbs'] = array(
	array($forum_config['o_board_title'], forum_link($forum_url['index'])),
	array($lang_admin_common['Forum administration'], forum_link($forum_url['admin_index'])),
	'Новая тема'
);
	
define('FORUM_PAGE', 'post');
define('FORUM_PAGE_SECTION', 'pan_posting');
require FORUM_ROOT.'header.php';

// START SUBST - <!-- forum_main -->
ob_start();

//($hook = get_hook('hd_head')) ? eval($hook) : null; 
?>
<script>
function getForumId(fid){
	var gDate = document.getElementById("get_date").value;
	var gTime = document.getElementById("get_time").value;
	jQuery.ajax({
		url:	"<?php echo $base_url.'/extensions/panbb_posting/ajax/list_users.php' ?>",
		type:	"POST",
		dataType: "html",
		data: ({gtime: gTime, gdate: gDate }),
		success: function(response){
			document.getElementById("result_div_id").innerHTML = response;},
		error: function(response){
			document.getElementById("result_div_id").innerHTML = "Ошибка при отправке формы";}
	});
}
</script>

	<div class="main-subhead">
		<h2 class="hn"><span><?php echo $lang_post['Compose your topic'] ?></span></h2>
	</div>
	
	<div id="post-form" class="main-content main-frm">
<?php

	if (!empty($forum_page['text_options']))
		echo "\t\t".'<p class="ct-options options">'.sprintf($lang_common['You may use'], implode(' ', $forum_page['text_options'])).'</p>'."\n";

	// If there were any errors, show them
	if (!empty($errors))
	{
		$forum_page['errors'] = array();
		foreach ($errors as $cur_error)
			$forum_page['errors'][] = '<li class="warn"><span>'.$cur_error.'</span></li>';

?>
		<div class="ct-box error-box">
			<h2 class="warn hn"><?php echo $lang_post['Post errors'] ?></h2>
			<ul class="error-list">
				<?php echo implode("\n\t\t\t\t", $forum_page['errors'])."\n" ?>
			</ul>
		</div>
<?php
	}
?>
		<div id="req-msg" class="req-warn ct-box error-box">
			<p class="important"><?php echo $lang_common['Required warn'] ?></p>
		</div>
		<form class="frm-form" method="post" accept-charset="utf-8" action="<?php echo forum_link($forum_url['pan_posting_new_topic'], $fid) ?>">
			<div class="hidden">
				<input type="hidden" name="csrf_token" value="<?php echo generate_form_token(forum_link($forum_url['pan_posting_new_topic'], $fid)) ?>" />
			</div>

			<fieldset class="frm-group frm-hdgroup group">
				<legend class="group-legend"><strong>Add rank legend</strong></legend>
				<fieldset class="mf-set set">
					<legend><span><?php echo 'Дата' ?></span></legend>
					<div class="mf-box">

						<div class="mf-field text">
							<label for="fld<?php echo ++$forum_page['fld_count'] ?>"><span class="fld-label"></span></label><br />
							<span class="fld-input"><input type="date" id="get_date" name="req_date" onchange="getForumId(this.value);" value="<?php echo isset($req_time) ? $req_time : date("Y-m-d", time()) ?>" size="20" /></span>
						</div>

						<div class="mf-field text">
							<label for="fld<?php echo ++$forum_page['fld_count'] ?>"><span class="fld-label"></span></label><br />
							<span class="fld-input"><input type="time" id="get_time" name="req_time"  onchange="getForumId(this.value);" value="<?php echo isset($req_time) ? $req_time : date("H:i", time()) ?>" size="20" /></span>
						</div>

					</div>
				</fieldset>
			</fieldset>

			<div id="result_div_id"></div>

<?php
	// Reset counters
	$forum_page['group_count'] = $forum_page['item_count'] = 0;
?>
			<fieldset class="frm-group group">
				<legend class="group-legend"><strong><?php echo $lang_common['Required information'] ?></strong></legend>

				<div class="sf-set set">
					<div class="sf-box text required longtext">
						<label for="fld"><span><?php echo $lang_post['Topic subject'] ?></span></label><br />
						<span class="fld-input"><input id="fld" type="text" name="req_subject" value="<?php if (isset($_POST['req_subject'])) echo forum_htmlencode($subject); ?>" size="70" maxlength="70" required /></span>
					</div>
				</div>
<?php ($hook = get_hook('po_pre_post_contents')) ? eval($hook) : null; ?>
				<div class="txt-set set">
					<div class="txt-box textarea required">
						<label for="fld"><span><?php echo $lang_post['Write message'] ?></span></label>
						<div class="txt-input"><span class="fld-input"><textarea id="fld" name="req_message" rows="15" cols="95" required spellcheck="true"><?php echo isset($_POST['req_message']) ? forum_htmlencode($message) : (isset($forum_page['quote']) ? forum_htmlencode($forum_page['quote']) : '') ?></textarea></span></div>
					</div>
				</div>
			</fieldset>

			<div class="frm-buttons">
				<span class="submit primary"><input type="submit" name="add_topic" value="<?php echo $lang_post['Submit topic'] ?>" /></span>
			</div>
		</form>
		
	</div>
	
<?php
$tpl_temp = forum_trim(ob_get_contents());
$tpl_main = str_replace('<!-- forum_main -->', $tpl_temp, $tpl_main);
ob_end_clean();
// END SUBST - <!-- forum_main -->

require FORUM_ROOT.'footer.php';